@@ -1264,6 +1264,7 @@ evdev_read_model_flags(struct evdev_device *device)
 		MODEL(APPLE_TOUCHPAD_ONEBUTTON),
 		MODEL(LOGITECH_MARBLE_MOUSE),
 		MODEL(TABLET_NO_PROXIMITY_OUT),
+		MODEL(MS_NANO_TRANSCEIVER),
 #undef MODEL
 		{ "ID_INPUT_TRACKBALL", EVDEV_MODEL_TRACKBALL },
 		{ NULL, EVDEV_MODEL_DEFAULT },
@@ -1917,6 +1918,11 @@ evdev_device_create(struct libinput_seat *seat,
 	const char *devnode = udev_device_get_devnode(udev_device);
 	const char *sysname = udev_device_get_sysname(udev_device);
 
+	if (!devnode) {
+		log_info(libinput, "%s: no device node associated\n", sysname);
+		return NULL;
+	}
+
 	if (udev_device_should_be_ignored(udev_device)) {
 		log_debug(libinput, "%s: device is ignored\n", sysname);
 		return NULL;
@@ -2434,6 +2440,9 @@ evdev_device_resume(struct evdev_device *device)
 		return -ENODEV;
 
 	devnode = udev_device_get_devnode(device->udev_device);
+	if (!devnode)
+		return -ENODEV;
+
 	fd = open_restricted(libinput, devnode,
 			     O_RDWR | O_NONBLOCK | O_CLOEXEC);
 
