@@ -26,12 +26,6 @@
 #include "litest.h"
 #include "litest-int.h"
 
-static void litest_mouse_setup(void)
-{
-	struct litest_device *d = litest_create_device(LITEST_MOUSE);
-	litest_set_current_device(d);
-}
-
 static struct input_id input_id = {
 	.bustype = 0x3,
 	.vendor = 0x17ef,
@@ -48,15 +42,13 @@ static int events[] = {
 	-1 , -1,
 };
 
-struct litest_test_device litest_mouse_device = {
+TEST_DEVICE("mouse",
 	.type = LITEST_MOUSE,
 	.features = LITEST_RELATIVE | LITEST_BUTTON | LITEST_WHEEL,
-	.shortname = "mouse",
-	.setup = litest_mouse_setup,
 	.interface = NULL,
 
 	.name = "Lenovo Optical USB Mouse",
 	.id = &input_id,
 	.absinfo = NULL,
 	.events = events,
-};
+)
