@@ -30,13 +30,6 @@
 #include "litest.h"
 #include "litest-int.h"
 
-static void
-litest_synaptics_hover_setup(void)
-{
-	struct litest_device *d = litest_create_device(LITEST_SYNAPTICS_HOVER_SEMI_MT);
-	litest_set_current_device(d);
-}
-
 static struct input_event down[] = {
 	{ .type = EV_ABS, .code = ABS_X, .value = LITEST_AUTO_ASSIGN  },
 	{ .type = EV_ABS, .code = ABS_Y, .value = LITEST_AUTO_ASSIGN },
@@ -118,11 +111,9 @@ static const char udev_rule[] =
 "\n"
 "LABEL=\"synaptics_semi_mt_end\"";
 
-struct litest_test_device litest_synaptics_hover_device = {
+TEST_DEVICE("synaptics-hover",
 	.type = LITEST_SYNAPTICS_HOVER_SEMI_MT,
 	.features = LITEST_TOUCHPAD | LITEST_SEMI_MT | LITEST_BUTTON,
-	.shortname = "synaptics hover",
-	.setup = litest_synaptics_hover_setup,
 	.interface = &interface,
 
 	.name = "SynPS/2 Synaptics TouchPad",
@@ -130,4 +121,4 @@ struct litest_test_device litest_synaptics_hover_device = {
 	.events = events,
 	.absinfo = absinfo,
 	.udev_rule = udev_rule,
-};
+)
