@@ -31,15 +31,6 @@
 #include "litest.h"
 #include "litest-int.h"
 
-static void litest_wacom_cintiq_pad_setup(void)
-{
-	struct litest_device *d;
-
-	d = litest_create_device(LITEST_WACOM_CINTIQ_24HDT_PAD);
-
-	litest_set_current_device(d);
-}
-
 static void
 litest_wacom_cintiq_pad_teardown(void)
 {
@@ -131,11 +122,9 @@ static const char udev_rule[] =
 "\n"
 "LABEL=\"pad_end\"";
 
-struct litest_test_device litest_wacom_cintiq_24hdt_pad_device = {
+TEST_DEVICE("wacom-cintiq-24hdt-pad",
 	.type = LITEST_WACOM_CINTIQ_24HDT_PAD,
 	.features = LITEST_TABLET_PAD | LITEST_RING,
-	.shortname = "wacom-cintiq-24hdt-pad",
-	.setup = litest_wacom_cintiq_pad_setup,
 	.teardown = litest_wacom_cintiq_pad_teardown,
 	.interface = &interface,
 
@@ -144,4 +133,4 @@ struct litest_test_device litest_wacom_cintiq_24hdt_pad_device = {
 	.events = events,
 	.absinfo = absinfo,
 	.udev_rule = udev_rule,
-};
+)
