@@ -26,13 +26,6 @@
 #include "litest.h"
 #include "litest-int.h"
 
-static void
-litest_wacom_ekr_setup(void)
-{
-	struct litest_device *d = litest_create_device(LITEST_WACOM_EKR);
-	litest_set_current_device(d);
-}
-
 static struct input_event down[] = {
 	{ .type = -1, .code = -1 },
 };
@@ -116,11 +109,9 @@ static const char udev_rule[] =
 "\n"
 "LABEL=\"pad_end\"";
 
-struct litest_test_device litest_wacom_ekr_device = {
+TEST_DEVICE("wacom-ekr",
 	.type = LITEST_WACOM_EKR,
 	.features = LITEST_TABLET_PAD | LITEST_RING,
-	.shortname = "wacom-ekr",
-	.setup = litest_wacom_ekr_setup,
 	.interface = &interface,
 
 	.name = "Wacom Express Key Remote Pad",
@@ -128,4 +119,4 @@ struct litest_test_device litest_wacom_ekr_device = {
 	.events = events,
 	.absinfo = absinfo,
 	.udev_rule = udev_rule,
-};
+)
