@@ -26,12 +26,6 @@
 #include "litest.h"
 #include "litest-int.h"
 
-static void litest_wacom_hid4800_tablet_setup(void)
-{
-	struct litest_device *d = litest_create_device(LITEST_WACOM_HID4800_PEN);
-	litest_set_current_device(d);
-}
-
 static struct input_event proximity_in[] = {
 	{ .type = EV_ABS, .code = ABS_X, .value = LITEST_AUTO_ASSIGN },
 	{ .type = EV_ABS, .code = ABS_Y, .value = LITEST_AUTO_ASSIGN },
@@ -104,15 +98,13 @@ static int events[] = {
 	-1, -1,
 };
 
-struct litest_test_device litest_wacom_hid4800_tablet_device = {
+TEST_DEVICE("wacom-hid4800-tablet",
 	.type = LITEST_WACOM_HID4800_PEN,
 	.features = LITEST_TABLET,
-	.shortname = "wacom-hid4800-tablet",
-	.setup = litest_wacom_hid4800_tablet_setup,
 	.interface = &interface,
 
 	.name = "Wacom HID 4800 Pen",
 	.id = &input_id,
 	.events = events,
 	.absinfo = absinfo,
-};
+)
