@@ -26,12 +26,6 @@
 #include "litest.h"
 #include "litest-int.h"
 
-static void litest_waltop_tablet_setup(void)
-{
-	struct litest_device *d = litest_create_device(LITEST_WALTOP);
-	litest_set_current_device(d);
-}
-
 static struct input_event proximity_in[] = {
 	{ .type = EV_ABS, .code = ABS_X, .value = LITEST_AUTO_ASSIGN },
 	{ .type = EV_ABS, .code = ABS_Y, .value = LITEST_AUTO_ASSIGN },
@@ -236,11 +230,9 @@ static const char udev_rule[] =
 "\n"
 "LABEL=\"waltop_end\"";
 
-struct litest_test_device litest_waltop_tablet_device = {
+TEST_DEVICE("waltop-tablet",
 	.type = LITEST_WALTOP,
 	.features = LITEST_TABLET | LITEST_WHEEL | LITEST_TILT,
-	.shortname = "waltop-tablet",
-	.setup = litest_waltop_tablet_setup,
 	.interface = &interface,
 
 	.name = "         WALTOP     Batteryless Tablet ", /* sic */
@@ -248,4 +240,4 @@ struct litest_test_device litest_waltop_tablet_device = {
 	.events = events,
 	.absinfo = absinfo,
 	.udev_rule = udev_rule,
-};
+)
